﻿package {
	import flash.display.*;
	import flash.text.*;
	import flash.events.*;
	import flash.net.URLLoader;
	import flash.net.URLRequest;
	
	public class trivia extends MovieClip {
		// game state variables
		private var questionNum:int;
		private var correctAnswer:String;
		private var numQuestions:int;
		private var numCorrect:int;
		private var answers:Array;
		// sprites and play_btn
		private var gameSprite:Sprite;
		private var questionSprite:Sprite;
		private var answerSprites:Sprite;
		private var playBtn:play_btn;
		// text fields
		private var feedbackField:TextField;
		private var questionField:TextField;
		private var scoreField:TextField;
		// text formats
		private var questionFormat:TextFormat;
		private var answerFormat:TextFormat;
		private var scoreFormat:TextFormat;
		// data
		private var dataXML:XML;
		
		public function playTrivia() {
			//create game sprite
			gameSprite = new Sprite();
			addChild(gameSprite);
			//create text formats
			questionFormat = new TextFormat("Arial",18,0x000000,true,false,false,null,null,"center");
			answerFormat = new TextFormat("Arial",18,0x000000,true,false,false,null,null,"left");
			scoreFormat = new TextFormat("Arial",18,0x000000,true,false,false,null,null,"center");			
			// create score field and intial feedback text
			scoreField = createText("",questionFormat,gameSprite,0,360,550);
			feedbackField = createText("Loading questions...",questionFormat,gameSprite,0,50,550);
			//setup game and load questions
			questionNum = 0;
			numQuestions = 0;
			numCorrect = 0;
			updateScore();
			xmlImport();
		}
		
		//load questions
		public function xmlImport() {
			var xmlURL:URLRequest = new URLRequest("trivia.xml");
			var xmlLoader:URLLoader = new URLLoader(xmlURL);
			xmlLoader.addEventListener(Event.COMPLETE,xmlLoaded);
		}
		
		//questions loaded
		public function xmlLoaded(event:Event) {
			dataXML = XML(event.target.data);
			gameSprite.removeChild(feedbackField);
			feedbackField = createText("Click Play when Ready!",questionFormat,gameSprite,0,60,550);
			showPlayButton("Play");
		}
		
		//create text field
		public function createText(text:String,tf:TextFormat,s:Sprite,x,y:Number, width:Number): TextField {
			var tField:TextField = new TextField();
			tField.x = x;
			tField.y = y;
			tField.width = width;
			tField.defaultTextFormat = tf;
			tField.selectable = false;
			tField.multiline = true;
			tField.wordWrap = true;
			if (tf.align == "left") {
				tField.autoSize = TextFieldAutoSize.LEFT;
			} else {
				tField.autoSize = TextFieldAutoSize.CENTER;
			}
			tField.text = text;
			s.addChild(tField);
			return tField;
		}
		
		//update score
		public function updateScore() {
			scoreField.text = "Number of questions: " + numQuestions + "           Number correct: " + numCorrect;
		}
		
		//ready for next question?
		public function showPlayButton(buttonLabel:String) {
			playBtn = new play_btn();
			playBtn.label.text = buttonLabel;
			playBtn.x = 220;
			playBtn.y = 300;
			gameSprite.addChild(playBtn);
			playBtn.addEventListener(MouseEvent.CLICK,clickedPlayButton);
		}
		
		//player ready
		public function clickedPlayButton(event:MouseEvent) {

			if (questionSprite != null) {
				gameSprite.removeChild(questionSprite);
			}
			//remove button and message
			gameSprite.removeChild(playBtn);
			gameSprite.removeChild(feedbackField);
			//ask next question
			if (questionNum >= dataXML.child("*").length()) {
				gotoAndStop("gameover");
			} else {
				askQuestion();
			}
		}
		
		//ask question
		public function askQuestion() {

			questionSprite = new Sprite();
			gameSprite.addChild(questionSprite);
			//create question text field
			var question:String = dataXML.item[questionNum].question;
			questionField = createText(question,questionFormat,questionSprite,0,60,550);
			//create answer sprite
			correctAnswer = dataXML.item[questionNum].answers.answer[0];
			answers = shuffleAnswers(dataXML.item[questionNum].answers);
			//each answer in new sprite with answerButton
			answerSprites = new Sprite();
			for (var i:int=0; i < answers.length; i++) {
				var answer:String = answers[i];
				var answerSprite:Sprite = new Sprite();
				var letter:String = String.fromCharCode(65+i); //A-D
				var answerField:TextField = createText(answer,answerFormat,answerSprite,0,0,450);
				var answerBtn:answer_btn = new answer_btn(); //in library
				answerBtn.letter.text = letter;
				answerSprite.x = 100;
				answerSprite.y = 150+i*50;
				answerSprite.addChild(answerBtn);
				answerSprite.addEventListener(MouseEvent.CLICK,clickAnswer);
				answerSprite.buttonMode = true;
				answerSprites.addChild(answerSprite);
			}
			questionSprite.addChild(answerSprites);
		}
		
		//shuffle answers in array
		public function shuffleAnswers(answers:XMLList) {
			var shuffledAnswers:Array = new Array();
			while (answers.child("*").length() > 0) {
				var r:int = Math.floor(Math.random()*answers.child("*").length());
				shuffledAnswers.push(answers.answer[r]);
				delete answers.answer[r];
			}
			return shuffledAnswers;
		}
		
		//player selects answer
		public function clickAnswer(event:MouseEvent) {
			var selectedAnswer = event.currentTarget.getChildAt(0).text;
			if (selectedAnswer == correctAnswer) {
				numCorrect++;
				feedbackField = createText("Way to go!",questionFormat,gameSprite,0,140,550);
			} else {
				feedbackField = createText("Sorry you're wrong! The correct answer is: ",questionFormat,gameSprite,0,140,550);
			}
			finishQuestion();
		}
		
		public function finishQuestion() {
			for (var i:int=0; i < 4; i++) {
				answerSprites.getChildAt(i).removeEventListener(MouseEvent.CLICK,clickAnswer);
				if (answers[i] != correctAnswer) {
					answerSprites.getChildAt(i).visible = false;
				} else {
					answerSprites.getChildAt(i).y = 200;
				}
			}
			//next question
			questionNum++;
			numQuestions++;
			updateScore();
			showPlayButton("Next");
		}
		
		//clean up
		public function cleanup() {
			removeChild(gameSprite);
			gameSprite = null;
			questionSprite = null;
			answerSprites = null;
			dataXML = null;
		}
	}
}
		